==> CRM64Pro-0.14.0-docs.zip: CRM64Pro-0.14.0-docs/html/class_c_r_m64_pro_1_1_x_m_l.js <==
var class_c_r_m64_pro_1_1_x_m_l =
[
    [ "info", "class_c_r_m64_pro_1_1_x_m_l.html#ad9e0cd6aa8d92f4a885b3d43c30cc112", null ],
    [ "getName", "class_c_r_m64_pro_1_1_x_m_l.html#a9ec90917bb240142597c847d248797ba", null ],
    [ "getID", "class_c_r_m64_pro_1_1_x_m_l.html#aab407e3c9f4a348f8c442ae25333b3a9", null ],
    [ "nodePointTo", "class_c_r_m64_pro_1_1_x_m_l.html#a4744a30e3d66d6fca90e6dec4f18d611", null ],
    [ "nodeFirst", "class_c_r_m64_pro_1_1_x_m_l.html#aece52fc751a2e7528d3df54b3a86c5bd", null ],
    [ "nodeNext", "class_c_r_m64_pro_1_1_x_m_l.html#a9e1235867c2b89dcdcfb9890e4c2ff55", null ],
    [ "nodePrev", "class_c_r_m64_pro_1_1_x_m_l.html#a4c17e838f4c22a0686575ad410e0340c", null ],
    [ "nodeParent", "class_c_r_m64_pro_1_1_x_m_l.html#ae5b3ee75cb926b3d186e1c79c1bda9d0", null ],
    [ "nodeChild", "class_c_r_m64_pro_1_1_x_m_l.html#a6e66fe78ea4d19866049e437f4336dda", null ],
    [ "nodeStore", "class_c_r_m64_pro_1_1_x_m_l.html#af206edc0b2e554739a5b2925bf11dee1", null ],
    [ "nodeRestore", "class_c_r_m64_pro_1_1_x_m_l.html#a17b29619289ec5ba1d50c4f1d1a166e2", null ],
    [ "nodeRemove", "class_c_r_m64_pro_1_1_x_m_l.html#a5a1add4d35318c4505fcdf86c8884197", null ],
    [ "nodeCreate", "class_c_r_m64_pro_1_1_x_m_l.html#a51864d6285d7e077fd9e1ce927b774b7", null ],
    [ "nodeRename", "class_c_r_m64_pro_1_1_x_m_l.html#a256cf6a77392163d13346916a75f1353", null ],
    [ "nodeGetName", "class_c_r_m64_pro_1_1_x_m_l.html#a6fec77c5a8f355aec5d4a67677855a73", null ],
    [ "setAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#ab0872262230ed21dff88ec3cf73e94ef", null ],
    [ "setAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a7a577d55ff6e95ebbd1853af45a830b5", null ],
    [ "setAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a82ee6db2de7808ef25232d391dfdaae1", null ],
    [ "getAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a303997dc9e4baedae5f73679c4dee1d3", null ],
    [ "getAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a2787929a8359da3110b848cc618c616d", null ],
    [ "getAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a256f00aa2ac48e1f81c96f191b16aced", null ],
    [ "removeAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a4cbcbde8f37dd4a36ccafbccfb0e7957", null ],
    [ "setText", "class_c_r_m64_pro_1_1_x_m_l.html#a89965f837618f1c5648ddadf91583cdd", null ],
    [ "getText", "class_c_r_m64_pro_1_1_x_m_l.html#a9c0f86ff43c57dab467e032e8432176f", null ],
    [ "removeText", "class_c_r_m64_pro_1_1_x_m_l.html#a8d94fd07f21ad8fc86e1b45c29a4887b", null ],
    [ "setComment", "class_c_r_m64_pro_1_1_x_m_l.html#a5b0d151912514c351619b410293fb672", null ],
    [ "getComment", "class_c_r_m64_pro_1_1_x_m_l.html#aa0d2514219fb5cb094209d6049ff3a4d", null ],
    [ "removeComment", "class_c_r_m64_pro_1_1_x_m_l.html#a792738be7b3cc01843f8c712fa514735", null ],
    [ "saveToFile", "class_c_r_m64_pro_1_1_x_m_l.html#a2a2981b92e37f6870050bf4ddb317ab3", null ],
    [ "save", "class_c_r_m64_pro_1_1_x_m_l.html#a79cfe81ca592580cd5102fe1b2a7beef", null ],
    [ "save", "class_c_r_m64_pro_1_1_x_m_l.html#a74375b72a752daca63ea323bf0d2cc73", null ]
];

==> CRM64Pro-0.15.0-docs.zip: CRM64Pro-0.15.0-docs/html/class_c_r_m64_pro_1_1_x_m_l.js <==
var class_c_r_m64_pro_1_1_x_m_l =
[
    [ "info", "class_c_r_m64_pro_1_1_x_m_l.html#ad9e0cd6aa8d92f4a885b3d43c30cc112", null ],
    [ "getName", "class_c_r_m64_pro_1_1_x_m_l.html#a9ec90917bb240142597c847d248797ba", null ],
    [ "getID", "class_c_r_m64_pro_1_1_x_m_l.html#aab407e3c9f4a348f8c442ae25333b3a9", null ],
    [ "nodePointTo", "class_c_r_m64_pro_1_1_x_m_l.html#afe6ea78b367aec9dcf6e43793d778902", null ],
    [ "nodeFirst", "class_c_r_m64_pro_1_1_x_m_l.html#aece52fc751a2e7528d3df54b3a86c5bd", null ],
    [ "nodeNext", "class_c_r_m64_pro_1_1_x_m_l.html#a9e1235867c2b89dcdcfb9890e4c2ff55", null ],
    [ "nodePrev", "class_c_r_m64_pro_1_1_x_m_l.html#a4c17e838f4c22a0686575ad410e0340c", null ],
    [ "nodeParent", "class_c_r_m64_pro_1_1_x_m_l.html#ae5b3ee75cb926b3d186e1c79c1bda9d0", null ],
    [ "nodeChild", "class_c_r_m64_pro_1_1_x_m_l.html#a6e66fe78ea4d19866049e437f4336dda", null ],
    [ "nodeStore", "class_c_r_m64_pro_1_1_x_m_l.html#af206edc0b2e554739a5b2925bf11dee1", null ],
    [ "nodeRestore", "class_c_r_m64_pro_1_1_x_m_l.html#a17b29619289ec5ba1d50c4f1d1a166e2", null ],
    [ "nodeRemove", "class_c_r_m64_pro_1_1_x_m_l.html#a5a1add4d35318c4505fcdf86c8884197", null ],
    [ "nodeCreate", "class_c_r_m64_pro_1_1_x_m_l.html#a51864d6285d7e077fd9e1ce927b774b7", null ],
    [ "nodeRename", "class_c_r_m64_pro_1_1_x_m_l.html#a256cf6a77392163d13346916a75f1353", null ],
    [ "nodeGetName", "class_c_r_m64_pro_1_1_x_m_l.html#a6fec77c5a8f355aec5d4a67677855a73", null ],
    [ "hasAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a10b7b9c40283940e3c5f6c27531dbcf6", null ],
    [ "setAttributeString", "class_c_r_m64_pro_1_1_x_m_l.html#a76edffb63a5e7c46d70b34ef6a30c28f", null ],
    [ "setAttributeInt", "class_c_r_m64_pro_1_1_x_m_l.html#a14d64d2054d02591f5aac712c136bc92", null ],
    [ "setAttributeUint", "class_c_r_m64_pro_1_1_x_m_l.html#a1fd295f3b685cfc09f2c8927fde563a7", null ],
    [ "setAttributeFloat", "class_c_r_m64_pro_1_1_x_m_l.html#a2b238945dc810c1b54e9d08f511a2c5d", null ],
    [ "setAttributeBool", "class_c_r_m64_pro_1_1_x_m_l.html#a22f32d4ba0795be28bbe49f0158db6ad", null ],
    [ "getAttributeString", "class_c_r_m64_pro_1_1_x_m_l.html#a135e9e891d9d867aacb410f45e5a0d91", null ],
    [ "getAttributeInt", "class_c_r_m64_pro_1_1_x_m_l.html#a6a31f249aeb19702b29e7f8d68523577", null ],
    [ "getAttributeUint", "class_c_r_m64_pro_1_1_x_m_l.html#a5eac5be96f7101f1f9654bcedb05e618", null ],
    [ "getAttributeFloat", "class_c_r_m64_pro_1_1_x_m_l.html#a0e40c73ee7bb00831d94d404223b8297", null ],
    [ "getAttributeBool", "class_c_r_m64_pro_1_1_x_m_l.html#ad095890320b5d59a6e0f26a42b3e870a", null ],
    [ "removeAttribute", "class_c_r_m64_pro_1_1_x_m_l.html#a4cbcbde8f37dd4a36ccafbccfb0e7957", null ],
    [ "setText", "class_c_r_m64_pro_1_1_x_m_l.html#a89965f837618f1c5648ddadf91583cdd", null ],
    [ "getText", "class_c_r_m64_pro_1_1_x_m_l.html#a9c0f86ff43c57dab467e032e8432176f", null ],
    [ "removeText", "class_c_r_m64_pro_1_1_x_m_l.html#a8d94fd07f21ad8fc86e1b45c29a4887b", null ],
    [ "setComment", "class_c_r_m64_pro_1_1_x_m_l.html#a5b0d151912514c351619b410293fb672", null ],
    [ "getComment", "class_c_r_m64_pro_1_1_x_m_l.html#aa0d2514219fb5cb094209d6049ff3a4d", null ],
    [ "removeComment", "class_c_r_m64_pro_1_1_x_m_l.html#a792738be7b3cc01843f8c712fa514735", null ],
    [ "saveToFile", "class_c_r_m64_pro_1_1_x_m_l.html#a2a2981b92e37f6870050bf4ddb317ab3", null ],
    [ "save", "class_c_r_m64_pro_1_1_x_m_l.html#a79cfe81ca592580cd5102fe1b2a7beef", null ],
    [ "save", "class_c_r_m64_pro_1_1_x_m_l.html#a74375b72a752daca63ea323bf0d2cc73", null ]
];
